@@ -122,7 +122,11 @@ QString StorageAccess::filePath() const
         Device holderDevice(path);
         const auto mntPoints = qdbus_cast<QByteArrayList>(holderDevice.prop("MountPoints"));
         if (!mntPoints.isEmpty()) {
-            return QFile::decodeName(mntPoints.first()); // FIXME Solid doesn't support multiple mount points
+            QByteArray first = mntPoints.first();
+            if (first.endsWith('\x00')) {
+                first.chop(1);
+            }
+            return QFile::decodeName(first); // FIXME Solid doesn't support multiple mount points
         } else {
             return QString();
         }
@@ -406,8 +410,10 @@ bool StorageAccess::requestPassphrase()
 
     QString appId = QCoreApplication::applicationName();
 
-    // TODO KF6: remove hard dep on Plasma5 here which provides the SolidUiServer kded5 plugin
-    QDBusInterface soliduiserver("org.kde.kded5", "/modules/soliduiserver", "org.kde.SolidUiServer");
+    const auto plasmaVersionMajor = qEnvironmentVariable("KDE_SESSION_VERSION", "6");
+
+    // TODO KF6: remove hard dep on Plasma here which provides the SolidUiServer kded plugin
+    QDBusInterface soliduiserver(QStringLiteral("org.kde.kded") + plasmaVersionMajor, "/modules/soliduiserver", "org.kde.SolidUiServer");
     QDBusReply<void> reply = soliduiserver.call("showPassphraseDialog", udi, returnService, m_lastReturnObject, wId, appId);
     m_passphraseRequested = reply.isValid();
     if (!m_passphraseRequested) {
