@@ -54,20 +54,12 @@ public:
 
     virtual double temperature() const;
 
-
-
     virtual QString serial() const;
 
     // not yet implemented
     // ------------
     virtual bool isPresent() const;
 
-    virtual bool isRecalled() const;
-
-    virtual QString recallVendor() const;
-
-    virtual QString recallUrl() const;
-
     virtual qlonglong remainingTime() const;
 
     // ------------
@@ -121,8 +113,6 @@ private:
     QString m_serial;
     ulong m_temperature;
     ulong m_timeUntilEmpty;
-
-
 };
 }
 }
